#************************************************************ 
#
# Component       CNF  
#
# Synopsis        OpenBoot
#
#
# Copyright 2001 Sun Microsystems, Inc. All rights reserved.
#
#
#************************************************************
#
# #ident "@(#)OBP.pm 1.5 02/04/03 SMI"
#
#************************************************************

package OBP ;

use LOG ;
use CMM ;

#
#
#
my $G_category = "OBP" ;
my $G_load_done = FALSE ;

#
#  OBP related information
#
my $G_boot_device = "" ;
my $G_reboot = "" ;
my $G_local_mac_address = "" ;

#--------------------------------------------------------------
#
#  load
#
#      retrieve information related to boot
#
#--------------------------------------------------------------

sub load
  {
    if ($G_load_done eq TRUE)
      {
	return ;
      }
    $G_load_done = TRUE ;

    #
    #  get the OBP configuration by running 'eeprom' utility
    #

    LOG::print_msg(2,"    executing /usr/bin/uname -i...") ;
    chomp($L_platform = qx{/usr/bin/uname -i}) ;
    LOG::print_msg(2,"    -> platform: $L_platform...") ;
    LOG::print_msg(2,"    executing /usr/platform/$L_platform/sbin/eeprom...") ;
    @L_result = qx{/usr/platform/$L_platform/sbin/eeprom} ;
    foreach $L_line (@L_result)
      {
	chomp($L_line) ;
	LOG::print_msg(2,"    analyzing $L_line...") ;
	if ( $L_line =~ /^boot-device=(.*)/o)
	  {
	    $G_boot_device      = $1 ;
	    LOG::print_msg(2,"    -> Boot device: $G_boot_device") ;
	  }
	if ( $L_line =~ /^auto-boot\?=([0-9a-z]*)/o)
	  {
	    $G_autoboot         = $1 ;
	    LOG::print_msg(2,"    -> autoboot: $G_autoboot") ;
	  }
	if ( $L_line =~ /^local-mac-address\?=([0-9a-z]*)/o)
	  {
	    $G_local_mac_address  = $1 ;
	    LOG::print_msg(2,"    -> local-mac-address: $G_local_mac_address") ;
	  }
      }
  }

#--------------------------------------------------------------
#
#  check_installation
#
#      check boot information in function of the node role
#
#--------------------------------------------------------------

sub check_customization
  {
    my $L_test = "" ;

    LOG::print_msg(0, "") ;
    LOG::print_msg(0, "OBP checking") ;
    LOG::print_msg(0, "") ;

    load ;

    #
    #  check if the boot device type is valid for the node type
    #
    $L_status = OK ;
    if (OS::guess_if_master_eligible eq TRUE)
      {
	$L_test = "boot-device must look like 'disk'" ;
	if ($G_boot_device !~ m/^[^\s\t]*disk/)
	  {
	    $L_status = FAILED ;
	  }
      }
    else
      {
	$L_test = "boot-device must look like 'net:dhcp net2:dhcp'" ;
	if ($G_boot_device !~ m/^(net:dhcp[0-9,]*[\s\t]*net2:dhcp[0-9,]*)/)
	  {
	    $L_status = FAILED ;
	  }
      }
     LOG::print_result($L_test, $L_status) ;

    #
    #  check if OBP is set in auto reboot mode
    #
    $L_test = "auto-boot must be set to 'true'" ;
    $L_status = OK ;
    if ($G_autoboot ne "true")
      {
	$L_status = FAILED ;
      }
    LOG::print_result($L_test, $L_status) ;

    #
    #  check if local mac address is set to true
    #
    $L_test = "local-mac-address must be set to 'true'" ;
    $L_status = OK ;
    if ($G_local_mac_address ne "true")
      {
	$L_status = FAILED ;
      }
    LOG::print_result($L_test, $L_status) ;
  }

#--------------------------------------------------------------
#
#  main
#
#--------------------------------------------------------------

{
}
