#************************************************************ 
#
# Component      CNF  
#
# Synopsis       Reliable Boot Server
#
#
# Copyright 2001 Sun Microsystems, Inc. All rights reserved.
#
#
#************************************************************
#
# #ident "@(#)RBS.pm 1.6 02/03/15 SMI"
#
#************************************************************

#=head1 Reliable Boot Server
#
#=over 4
#
#=cut

package RBS ;

use LOG ;

$E_dhcp_configuration_file = "/etc/inet/dhcpsvc.conf" ;

my $G_status = OK ;


#--------------------------------------------------------------
#
#  rbs_installed
#
#--------------------------------------------------------------

sub rbs_installed
  {
    my $version ;
    my $name ;
    my $basedir ;

    my $return = OS::get_package("SUNWnhrbs", "LOCAL", 
				 \$version, \$name, \$basedir) ;
    if ($return eq OK) {
      return TRUE ;
    }
    if (($return eq NA) || ($return eq NOK)) {
      return FALSE ;
    }
  }
#--------------------------------------------------------------
#
#  get_parameter
#
#  1 : parameter name
#
#  return value of the parameter
#
#--------------------------------------------------------------

sub get_parameter
  {
    ($L_parameter) = @_ ;

    chomp($result = qx{/usr/bin/grep "[ \t]*${L_parameter}[ \t]*=" $E_dhcp_configuration_file}) ;

    LOG::print_msg(3, "dhcpsvc.conf grep: $result") ;
    if ($result eq "")
      {
	return "";
      }

    $result =~ s/#.*// ;
    $result =~ m/[\s\t]*([a-zA-Z0-9_]*)[\s\t]*=[\s\t]*([^\s\t]*)/ ;
    if ($1 ne $L_parameter)
      {
	return "" ;
      }

    LOG::print_msg(3, "$L_parameter value = $2") ;

    return $2 ;
}

#--------------------------------------------------------------
#
#  check_parameter
#
#  1 : parameter name
#  2 : parameter value
#
#  return value of the parameter
#
#--------------------------------------------------------------

sub check_parameter
  {
    ($L_parameter, $L_value) = @_ ;

    $value = get_parameter($L_parameter) ;
    if ($L_value eq "")
      {

#=item <parameter> not defined
#
#    The specified parameter must be defined in /etc/inet/dhcpsvc.conf.
#
#=cut

	LOG::print_error("$L_parameter not defined") ;
	$G_status = FAILED ;
	return ;
      }

    if ($L_value ne $value)
      {

#=item <parameter>: <current> instead of <expected>
#
#    Please set the correct value for the specified parameter in
#    /etc/inet/dhcpsvc.conf.
#
#=cut

	LOG::print_error("$L_parameter: $value instead of $L_value") ;
	$G_status = FAILED ;
      }
}

#--------------------------------------------------------------
#
#  check_customization
#
#    get info about a specified package
#
#    1 : in: name of the package
#
#    2 : out: version ofthe package
#
#    return TRUE if the package exists
#
#--------------------------------------------------------------

sub check_customization
  {
    if (OS::guess_if_master_eligible eq FALSE)
      {
	return ;
      }

    if (rbs_installed eq "FALSE") {
      return ;
    }

    LOG::print_msg(0,"");
    LOG::print_msg(0,"Reliable Boot Server checking");
    LOG::print_msg(0,"");

    $L_status = OK ;

    $L_test = "check $E_dhcp_configuration_file" ;
    if (OS::check_file($E_dhcp_configuration_file) ne TRUE)
      {
	LOG::print_result($L_test,FAILED) ;
	return ;
      } 

    #
    # parameter checking
    # 
    check_parameter("DAEMON_ENABLED", TRUE) ;
    check_parameter("RUN_MODE", "server") ;
    check_parameter("RESOURCE", "SUNWnhrbs") ;
    check_parameter("CONVER", 1) ;

    $L_value = get_parameter("PATH") ;
    if ($L_value eq "")
      {

#=item PATH not defined
#
#    PATH is not defined in /etc/inet/dhcpsvc.conf
#
#=cut

	LOG::print_error("PATH not defined") ;
	$G_status = FAILED
      }
    else
      {
	if (! -e $L_value)
	  {

#=item PATH does not reference a valid file (<file>)
#
#    Please check that the file referenced by PATH in /etc/inet/dhcpsvc.conf
#    exists or set PATH with the correct path name.
#
#=cut

	    LOG::print_error("PATH does not reference a valid file ($L_value)") ;
	    $G_status = FAILED
	  }
      }

    LOG::print_result($L_test,$G_status) ;
  }

#--------------------------------------------------------------
#
#  display
#
#      display information regarding Reliable Boot Server
#
#--------------------------------------------------------------

sub display
 { 
    print "\n" ;
    print "Reliable Boot Server\n" ;
    print "\n" ;    
  } 

#--------------------------------------------------------------
#
#  main
#
#--------------------------------------------------------------

#=back
#
#=cut

{
}
